NetworkConfig class

Network configuration

Constructors

NetworkConfig({required String name, required String rpcUrl, required String chainId, required BlockchainNetwork network, required bool isTestnet, Map<String, dynamic> additionalParams = const {}})
const

Properties

additionalParams Map<String, dynamic>
final
chainId String
final
hashCode int
The hash code for this object.
no setterinherited
isTestnet bool
final
name String
final
network BlockchainNetwork
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rpcUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited